@@ -1,4 +1,5 @@
 import time
+import json
 import requests
 import traceback
 
@@ -19,19 +20,25 @@ class BigQuery:
 
     def __init__(self, read_big_query_project = "trell-ds-common",
                        write_big_query_project = "trellatale",
-                       service_account_file_path="trell-ds-projects-common.json"):
+                       service_account_file_path="trell-ds-projects-common.json",
+                       service_account_cred=None):
 
         """
         initialisation method for BigQuery Connector
         :param str read_big_query_project : project used while reading from BigQuery
         :param str write_big_query_project: project used while writing into BigQuery
-        :param str service_account_file_path: project specific BigQuery Credential
+        :param str service_account_file_path: project specific BigQuery Credential file path
+        :param dict service_account_cred : project specific BigQuery Credential file content
         """
 
         self.READ_BIG_QUERY_PROJECT = read_big_query_project
         self.WRITE_BIG_QUERY_PROJECT = write_big_query_project
 
         try:
+            if service_account_cred is not None:
+                service_account_file_path = "service_account_cred.json"
+                with open(service_account_file_path, "w") as cred_content:
+                    json.dump(service_account_cred, cred_content)
             self.credentials = Credentials.from_service_account_file(service_account_file_path)
             self.bq_client = bigquery.Client(credentials=self.credentials, project=self.credentials.project_id)
         except Exception as err:
